@@ -55,8 +55,8 @@ public:
     void reloadUoidList();
 
     QList<uint> mUoidList;
-    IdentityManager *mIdentityManager = nullptr;
-    IdentityCombo *q = nullptr;
+    IdentityManager *const mIdentityManager = nullptr;
+    IdentityCombo *const q = nullptr;
 };
 
 void KIdentityManagement::IdentityComboPrivate::reloadCombo()
@@ -178,7 +178,7 @@ void IdentityCombo::slotIdentityManagerChanged()
 
 void IdentityCombo::slotEmitChanged(int idx)
 {
-    emit identityChanged(d->mUoidList.at(idx));
+    Q_EMIT identityChanged(d->mUoidList.at(idx));
 }
 
 void IdentityCombo::slotUpdateTooltip(uint uoid)
