@@ -42,32 +42,29 @@ class Q_DECL_HIDDEN KIdentityManagement::SignaturePrivate
 {
 public:
     SignaturePrivate(Signature *qq)
-        : type(Signature::Disabled)
-        , enabled(false)
-        , inlinedHtml(false)
-        , q(qq)
+        : q(qq)
     {
     }
 
     void assignFrom(const KIdentityManagement::Signature &that);
     void cleanupImages();
     void saveImages() const;
-    QString textFromFile(bool *ok) const;
-    QString textFromCommand(bool *ok) const;
+    Q_REQUIRED_RESULT QString textFromFile(bool *ok) const;
+    Q_REQUIRED_RESULT QString textFromCommand(bool *ok) const;
     void insertSignatureText(Signature::Placement placement, Signature::AddedText addedText, KPIMTextEdit::RichTextComposer *textEdit, bool forceDisplay) const;
 
     /// List of images that belong to this signature. Either added by addImage() or
     /// by readConfig().
-    QList<Signature::EmbeddedImagePtr> embeddedImages;
+    QVector<Signature::EmbeddedImagePtr> embeddedImages;
 
     /// The directory where the images will be saved to.
     QString saveLocation;
     QString path;
     QString text;
-    Signature::Type type;
+    Signature::Type type = Signature::Disabled;
     bool enabled = false;
     bool inlinedHtml = false;
-    Signature *q = nullptr;
+    Signature * const q = nullptr;
 };
 
 static bool isCursorAtEndOfLine(const QTextCursor &cursor)
@@ -221,7 +218,7 @@ void SignaturePrivate::saveImages() const
 {
     if (inlinedHtml && !saveLocation.isEmpty()) {
         for (const Signature::EmbeddedImagePtr &image : qAsConst(embeddedImages)) {
-            QString location = saveLocation + QLatin1Char('/') + image->name;
+            const QString location = saveLocation + QLatin1Char('/') + image->name;
             if (!image->image.save(location, "PNG")) {
                 qCWarning(KIDENTITYMANAGEMENT_LOG) << "Failed to save image" << location;
             }
@@ -284,7 +281,7 @@ QString SignaturePrivate::textFromCommand(bool *ok) const
     }
 
     // get output:
-    QByteArray output = proc.readAllStandardOutput();
+    const QByteArray output = proc.readAllStandardOutput();
 
     // TODO: hmm, should we allow other encodings, too?
     return QString::fromLocal8Bit(output.data(), output.size());
@@ -516,12 +513,12 @@ void Signature::insertIntoTextEdit(Placement placement, AddedText addedText, KPI
     d->insertSignatureText(placement, addedText, textEdit, forceDisplay);
 }
 
-QList<Signature::EmbeddedImagePtr> Signature::embeddedImages() const
+QVector<Signature::EmbeddedImagePtr> Signature::embeddedImages() const
 {
     return d->embeddedImages;
 }
 
-void Signature::setEmbeddedImages(const QList<Signature::EmbeddedImagePtr> &embedded)
+void Signature::setEmbeddedImages(const QVector<Signature::EmbeddedImagePtr> &embedded)
 {
     d->embeddedImages = embedded;
 }
@@ -542,7 +539,7 @@ QDataStream &KIdentityManagement::operator>>
     QString path;
     QString text;
     QString saveLocation;
-    QList<Signature::EmbeddedImagePtr> lst;
+    QVector<Signature::EmbeddedImagePtr> lst;
     bool enabled;
     stream >> s  >> path >> text >> saveLocation >> lst >> enabled;
     sig.setText(text);
