@@ -28,7 +28,8 @@
 #include <KShellCompletion>
 #include <KToolBar>
 #include <KMessageBox>
-#include <KRun>
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
 #include <QUrl>
 
 #include <KPIMTextEdit/RichTextComposer>
@@ -344,7 +345,7 @@ QString SignatureConfigurator::filePath() const
     // Force the filename to be relative to ~ instead of $PWD depending
     // on the rest of the code (KRun::run in Edit and KFileItem on save)
     if (!file.isEmpty() && QFileInfo(file).isRelative()) {
-        file = QDir::home().absolutePath() + QDir::separator() + file;
+        file = QDir::home().absolutePath() + QLatin1Char('/') + file;
     }
     return file;
 }
@@ -439,13 +440,14 @@ void SignatureConfigurator::slotUrlChanged()
 
 void SignatureConfigurator::slotEdit()
 {
-    QString url = filePath();
+    const QString url = filePath();
     // slotEnableEditButton should prevent this assert from being hit:
     assert(!url.isEmpty());
 
-    KRun::RunFlags flags;
-    flags |= KRun::DeleteTemporaryFiles;
-    KRun::runUrl(QUrl::fromLocalFile(url), QStringLiteral("text/plain"), this, flags);
+    KIO::OpenUrlJob *job = new KIO::OpenUrlJob(QUrl::fromLocalFile(url), QStringLiteral("text/plain"));
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+    job->setDeleteTemporaryFile(true);
+    job->start();
 }
 
 // "use HTML"-checkbox (un)checked
